abacusai.project_feature_group_schema — AbacusAI documentation

# abacusai.project_feature_group_schema

## Classes

`ProjectFeatureGroupSchema` | A schema description for a project feature group

## Module Contents

class abacusai.project_feature_group_schema.ProjectFeatureGroupSchema(client, nestedSchema=None, schema={}, duplicateFeatures={}, projectConfig={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A schema description for a project feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - nestedSchema (list) – List of schema of nested features

    - schema (Schema) – List of schema description for the feature

    - duplicateFeatures (Schema) – List of duplicate featureschemas

    - projectConfig (ProjectConfig) – Project-specific config for this feature group.

  nested_schema = None
  schema
  duplicate_features
  project_config
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict